% This Matlab script creates the figures used in the manuscript named: 
% "Multivariate and location-specific correlates of fuel consumption: A
% test track study"

% T. Melman Jan 2021
% t.melman@tudelft.nl
clc
close all
clearvars -except strc DataUBM_Interp Metrics Metrics_Averaged_Sub...
    DataUBM_Interp2 lding lding_total_all PltData

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% Initialization
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Files containing Experiment.name in the data.dir.dueca are analyzed.
% The data.conditions are the number of conditions and per condition and
% per repetition the data is analyzed for different metrics.
Exp.name = 'UBM_sections_All'; % This is the used name of the project

% Init
Exp.condition_plotName = {'Neutral' 'Eco'}; % ConditionNames used in plots
Exp.Context            = {'Highway' 'Mountain'};
Exp.formats            = {'png', 'fig'};
Exp.Markers            = {'o' 'x' 'square' '*'}; % Markers used for different conditions
Exp.ConditionLines     = {'-','--','-.','-'};
Exp.Total_sub          = 105;

% Set data directories//
% Change the current folder to the folder of this m-file.
if(~isdeployed)
    cd(fileparts(which(mfilename)));
end

home                             = pwd;
addpath(genpath(home));
addpath(genpath([home '\UsedFunctions'])); % Functions developed by T. Melman are included here.
Exp.dir.destination   = [home '\Data']; % Destination Path Analysis

% Color settings
[Exp.color, Exp.lightcolor] = specify_colors();

% Dock te figure window by default
set(0,'DefaultFigureWindowStyle','docked');

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% Start Analyzing
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% NOTE: The data is not added to this script due to its proprietary nature
% Load data
MatAlreadyExist = exist('strc');
if ~MatAlreadyExist
    cd(Exp.dir.destination);
    disp(['Loading data of ' sprintf('strc_%s',Exp.name) '...'])
    tic
    eval(sprintf('load strc_%s;',Exp.name));   % Load Experiment data
    eval(sprintf('strc = strc_%s;',Exp.name)); % Rename Experiment data as "spss"
      
    % Load interpolated data to road points, which is structured as 
    % dataUBM_Interp2.'(HW/MT)'.(rep,roadpoint,sub,Taskn,Vn) where:
    % HW: Highway route and MT is Mountain route
    % rep is number of repetitions per participant, 
    % roadpoint is the number of roadpoints (one roadpoint is 1m), 
    % sub = subject number (1-105), 
    % Taskn = Driving task number (1 = neutral, 2. Eco), 
    % Vn = vehicle number (1. Megane, 2. Clio)
    load DataUBM_Interp2
    
    % Load interpolated data to road points restructured compared to 
    % DataUBM_Interp2 (above). This datastructure allows for easy plotting
    % of average and STD over all participants as a function of distance.
    % DataUBM_Interp.HW.Vehicle(Vn).cond(cond).Speed(roadpoints,:).
    load DataUBM_Interp
    
    % Load calculated metrics that was used in the multivariate analysis
    % (all metrics)
    load Metrics
    
    % Metrics file where the metrics are averaged over repititions
    load Metrics_Averaged_Sub
    
    % PltData is used to create figure 2 (was easier to use a function that
    % I already wrote for it
    load PltData
    
    toc
    cd(home);
end


%% Make plot and show results
% The plots that are generated with "PlotAndSaveExperimentResults" are used
% to show the outputs for several metrics.
disp('Plotting experiment results...')

%% Make plots
% **Fig 1 in paper
MakeGPSPlot

% **Fig 2 in paper
Plot_average_results

% **Fig 3 in paper
CorrelationPlot

% **Fig 4 in paper
MultiVariateAnalyse

%% SituatedDependent Analysis (Duration 5-10 min)
% This function:
% 1. calculates the situation dependent correlations for all
%       drivers and trials (please see paper for explanation 
% 2. Creates Fig 5, Fig 6 & Fig 7
SituatedDependentAnalysis